@@ -54,7 +54,21 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
         super.destroy();
     }
 
-    _isInteresting() {
+    _fsIsRemote(root) {
+        return new Promise((resolve, reject) => {
+            const attr = Gio.FILE_ATTRIBUTE_FILESYSTEM_REMOTE;
+            root.query_filesystem_info_async(attr, null, (o, res) => {
+                try {
+                    const info = root.query_filesystem_info_finish(res);
+                    resolve(!info.get_attribute_boolean(attr));
+                } catch (e) {
+                    reject(e);
+                }
+            });
+        });
+    }
+
+    async _isInteresting() {
         if (!this.mount.can_eject() && !this.mount.can_unmount())
             return false;
         if (this.mount.is_shadowed())
@@ -62,17 +76,23 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
 
         let volume = this.mount.get_volume();
 
-        if (!volume) {
-            // probably a GDaemonMount, could be network or
-            // local, but we can't tell; assume it's local for now
-            return true;
+        if (volume)
+            return volume.get_identifier('class') !== 'network';
+
+        const root = this.mount.get_root();
+
+        try {
+            return await this._fsIsRemote(root);
+        } catch (e) {
+            log(`Failed to query filesystem: ${e.message}`);
         }
 
-        return volume.get_identifier('class') !== 'network';
+        // Hack, fall back to looking at GType
+        return Gio._LocalFilePrototype.isPrototypeOf(root);
     }
 
-    _syncVisibility() {
-        this.visible = this._isInteresting();
+    async _syncVisibility() {
+        this.visible = await this._isInteresting();
     }
 
     _eject() {
@@ -127,15 +147,12 @@ class DriveMenu extends PanelMenu.Button {
     _init() {
         super._init(0.0, _('Removable devices'));
 
-        let hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
         let icon = new St.Icon({
             icon_name: 'media-eject-symbolic',
             style_class: 'system-status-icon',
         });
 
-        hbox.add_child(icon);
-        hbox.add_child(PopupMenu.arrowIcon(St.Side.BOTTOM));
-        this.add_child(hbox);
+        this.add_child(icon);
 
         this._monitor = Gio.VolumeMonitor.get();
         this._addedId = this._monitor.connect('mount-added', (monitor, mount) => {
